Package: cOde
Type: Package
Title: Automated C Code Generation for 'deSolve', 'bvpSolve'
Version: 1.1.1
NeedsCompilation: no
Depends: R (>= 3.0)
Suggests: deSolve, bvpSolve, testthat
Date: 2022-02-23
Author: Daniel Kaschek
Maintainer: Daniel Kaschek <daniel.kaschek@gmail.com>
Description: Generates all necessary C functions allowing the user to work with
    the compiled-code interface of ode() and bvptwp(). The implementation supports
    "forcings" and "events". Also provides functions to symbolically compute
    Jacobians, sensitivity equations and adjoint sensitivities being the basis for
    sensitivity analysis.
License: GPL (>= 2)
RoxygenNote: 7.1.1
Packaged: 2022-02-23 21:44:17 UTC; kaschek
Repository: CRAN
Date/Publication: 2022-02-23 22:10:02 UTC
Built: R 4.4.0; ; 2024-05-23 15:39:31 UTC; unix
