# Generated by roxygen2: do not edit by hand

export(adjointSymb)
export(bvptwpC)
export(funC)
export(getSymbols)
export(jacobianSymb)
export(odeC)
export(prodSymb)
export(reduceSensitivities)
export(replaceNumbers)
export(replaceOperation)
export(replaceSymbols)
export(sensitivitiesSymb)
export(setForcings)
export(sumSymb)
importFrom(stats,D)
importFrom(stats,splinefun)
